// src/renderers/MeasuringEquipmentsRenderer.js
import { DCCRealListQuantity } from '../dccQuantity.js';

export class MeasuringEquipmentsRenderer {
    constructor(measuringEquipmentsData, language) {
        this.data = measuringEquipmentsData;
        this.language = language;
    }

    render() {
        // Create a container without an extra header (if you prefer to not duplicate the title)
        const container = document.createElement('div');
        // Optionally, you could add a header here if desired:
        // container.innerHTML = `<h3>Measuring Equipments</h3>`;

        let equipments = this.data && this.data['dcc:measuringEquipment'];
        if (!equipments) {
            container.textContent = 'No measuring equipments data available.';
            return container;
        }
        if (!Array.isArray(equipments)) {
            equipments = [equipments];
        }

        // Reset default browser styles for details and summary
        const detailsStyle = 'margin: 0; padding: 0; border: 1px solid #ccc; padding: 8px; margin-bottom: 10px;';
        const summaryStyle = 'margin: 0; padding: 0; list-style: none;';

        equipments.forEach(equipment => {
            // Each equipment is rendered in a collapsible details block.
            const details = document.createElement('details');
            details.setAttribute('style', detailsStyle);
            details.open = false; // collapsed by default

            // Create summary for collapsed view
            const summary = document.createElement('summary');
            summary.setAttribute('style', summaryStyle);
            // Equipment name (language‑specific)
            const eqName = this._getText(equipment['dcc:name']);
            // Manufacturer name (if available)
            const manufacturer = equipment['dcc:manufacturer']
                ? this._getText(equipment['dcc:manufacturer']['dcc:name'])
                : '';
            // Model
            const model = equipment['dcc:model'] ? equipment['dcc:model'] : '';
            // First identification (if available)
            let firstId = '';
            if (equipment['dcc:identifications'] && equipment['dcc:identifications']['dcc:identification']) {
                let ident = equipment['dcc:identifications']['dcc:identification'];
                if (!Array.isArray(ident)) { ident = [ident]; }
                const first = ident[0];
                firstId = `<small>${this._getText(first['dcc:name'])}: ${first['dcc:value']}</small>`;
            }
            summary.innerHTML = `<strong>${eqName}</strong> – ${manufacturer} – Model: ${model} – ${firstId}`;
            details.appendChild(summary);

            // Expanded content
            const contentDiv = document.createElement('div');
            contentDiv.style.marginTop = '8px';
            contentDiv.style.fontFamily = 'sans-serif';

            // Render full identifications
            if (equipment['dcc:identifications']) {
                const identDiv = document.createElement('div');
                identDiv.innerHTML = `<h4>Identifications</h4>`;
                let ident = equipment['dcc:identifications']['dcc:identification'];
                if (!Array.isArray(ident)) { ident = [ident]; }
                ident.forEach(id => {
                    const idName = this._getText(id['dcc:name']);
                    const idValue = id['dcc:value'] || '';
                    const issuer = id['dcc:issuer'] || '';
                    identDiv.innerHTML += `<p><small>${idName} (${issuer}): ${idValue}</small></p>`;
                });
                contentDiv.appendChild(identDiv);
            }

            // Render measuring equipment quantities as a table if available
            if (
                equipment['dcc:measuringEquipmentQuantities'] &&
                equipment['dcc:measuringEquipmentQuantities']['dcc:measuringEquipmentQuantity']
            ) {
                const qtyData = equipment['dcc:measuringEquipmentQuantities']['dcc:measuringEquipmentQuantity'];
                const quantities = Array.isArray(qtyData) ? qtyData : [qtyData];
                const table = document.createElement('table');
                table.style.width = '100%';
                table.style.borderCollapse = 'collapse';
                const headerRow = document.createElement('tr');
                ['Quantity', 'Value'].forEach(text => {
                    const th = document.createElement('th');
                    th.textContent = text;
                    th.style.border = '1px solid #ccc';
                    th.style.padding = '4px';
                    headerRow.appendChild(th);
                });
                table.appendChild(headerRow);
                quantities.forEach(q => {
                    const tr = document.createElement('tr');
                    const nameCell = document.createElement('td');
                    nameCell.style.border = '1px solid #ccc';
                    nameCell.style.padding = '4px';
                    nameCell.textContent = this._getText(q['dcc:name']);
                    tr.appendChild(nameCell);
                    const valueCell = document.createElement('td');
                    valueCell.style.border = '1px solid #ccc';
                    valueCell.style.padding = '4px';
                    // Render value and unit using DCCRealListQuantity
                    let qtyObj = new DCCRealListQuantity(q);
                    valueCell.innerHTML = qtyObj.getValues().join(' ') + ' ' + qtyObj.getUnit({ oneLine: true });
                    tr.appendChild(valueCell);
                    table.appendChild(tr);
                });
                contentDiv.appendChild(table);
            }

            details.appendChild(contentDiv);
            container.appendChild(details);
        });
        return container;
    }

    _getText(node) {
        if (!node) return '';
        const content = node['dcc:content'];
        if (Array.isArray(content)) {
            const match = content.find(item => item.$ && item.$.lang === this.language) || content[0];
            return match._ || match;
        }
        return content._ || content;
    }
}
